| Title: | What the Package Does (One Line, Title Case) |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Jimmy Briggs [aut, cre] (ORCID: <https://orcid.org/0000-0002-7489-8787>) |
| Maintainer: | Jimmy Briggs <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-12 07:54:56 UTC |
| Source: | https://github.com/jimbrig/browsr |
Use these functions to search the web directly from your browser, building advanced queries and supplying common useful R related domains.
Query Github's internal search engine.
Query a search on rseek.org.
Query a search on the R Nabble Forum. Nabble is an innovative search engine for R messages.
search_online(s, query_url = "https://google.com/search?q=") search_gh( s, type = "all", language = NULL, topic = NULL, user = NULL, org = NULL ) search_rseek(s) search_finzi(s) search_nabble(s) search_google(s) search_rproject(s) search_metacran(s)search_online(s, query_url = "https://google.com/search?q=") search_gh( s, type = "all", language = NULL, topic = NULL, user = NULL, org = NULL ) search_rseek(s) search_finzi(s) search_nabble(s) search_google(s) search_rproject(s) search_metacran(s)
s |
string to search for |
query_url |
string representing the URL to query; defaults to Google |
type |
what to search for, see details for options |
language |
optional language filter |
topic |
optional topic filter |
user |
optional user filter |
org |
optional org filter |
See https://cloud.r-project.org/search.html which showcases Google's advanced search feature to query only R-Project domain sites via the Google Search Engine.
search_gh:
search_rseek:
search_finzi:
search_nabble:
search_google:
search_rproject:
search_metacran:
library(browsr) # default search on google search_online("polished.tech") # search github (note: &ref=opensearch) search_online("polished", "https://github.com/search?q=%s&ref=opensearch") # search Github with language:r, org:tychobra for 'polished' (note: '%3A' represents a ':') search_online("polished", "https://github.com/search?q=%s+language%3Ar+org%3Atychobra") search_gh("websocket", language = "r", topic = "rshiny") # search your org search_gh("polished", org = "tychobra")library(browsr) # default search on google search_online("polished.tech") # search github (note: &ref=opensearch) search_online("polished", "https://github.com/search?q=%s&ref=opensearch") # search Github with language:r, org:tychobra for 'polished' (note: '%3A' represents a ':') search_online("polished", "https://github.com/search?q=%s+language%3Ar+org%3Atychobra") search_gh("websocket", language = "r", topic = "rshiny") # search your org search_gh("polished", org = "tychobra")